# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.0
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.finance_information_bank_deposits import FinanceInformationBankDeposits  # noqa: E501

class TestFinanceInformationBankDeposits(unittest.TestCase):
    """FinanceInformationBankDeposits unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FinanceInformationBankDeposits:
        """Test FinanceInformationBankDeposits
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FinanceInformationBankDeposits`
        """
        model = FinanceInformationBankDeposits()  # noqa: E501
        if include_optional:
            return FinanceInformationBankDeposits(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                period = empire_platform_api_public_client.models.finance_information_lockable_period.FinanceInformationLockablePeriod(
                    validity_from = empire_platform_api_public_client.models.finance_information_lockable_date.FinanceInformationLockableDate(
                        date = 'Tue Jan 04 00:00:00 UTC 2022', 
                        locked = True, ), 
                    validity_to = empire_platform_api_public_client.models.finance_information_lockable_date.FinanceInformationLockableDate(
                        date = 'Tue Jan 04 00:00:00 UTC 2022', 
                        locked = True, ), 
                    amount = empire_platform_api_public_client.models.finance_information_lockable_amount.FinanceInformationLockableAmount(
                        amount = 1.337, 
                        locked = True, ), )
            )
        else:
            return FinanceInformationBankDeposits(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                period = empire_platform_api_public_client.models.finance_information_lockable_period.FinanceInformationLockablePeriod(
                    validity_from = empire_platform_api_public_client.models.finance_information_lockable_date.FinanceInformationLockableDate(
                        date = 'Tue Jan 04 00:00:00 UTC 2022', 
                        locked = True, ), 
                    validity_to = empire_platform_api_public_client.models.finance_information_lockable_date.FinanceInformationLockableDate(
                        date = 'Tue Jan 04 00:00:00 UTC 2022', 
                        locked = True, ), 
                    amount = empire_platform_api_public_client.models.finance_information_lockable_amount.FinanceInformationLockableAmount(
                        amount = 1.337, 
                        locked = True, ), ),
        )
        """

    def testFinanceInformationBankDeposits(self):
        """Test FinanceInformationBankDeposits"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.0
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class InvoiceTypeWithNettingStatement(str, Enum):
    """
    InvoiceTypeWithNettingStatement
    """

    """
    allowed enum values
    """
    NS = 'NS'
    SB = 'SB'
    SC = 'SC'
    SI = 'SI'

    @classmethod
    def from_json(cls, json_str: str) -> InvoiceTypeWithNettingStatement:
        """Create an instance of InvoiceTypeWithNettingStatement from a JSON string"""
        return InvoiceTypeWithNettingStatement(json.loads(json_str))


